@@ -1,7 +1,7 @@
 import logging
 from grpc import StatusCode
 from grpc.aio import ServerInterceptor, AioRpcError
-from prometheus_client import Counter, Histogram, REGISTRY
+from prometheus_client import Counter, Histogram, REGISTRY, PROCESS_COLLECTOR, PLATFORM_COLLECTOR
 from prometheus_client.registry import CollectorRegistry
 from timeit import default_timer
 
@@ -11,28 +11,32 @@ CLIENT_STREAMING = "CLIENT_STREAMING"
 BIDI_STREAMING = "BIDI_STREAMING"
 UNKNOWN = "UNKNOWN"
 
+REGISTRY.unregister(PROCESS_COLLECTOR)
+REGISTRY.unregister(PLATFORM_COLLECTOR)
+REGISTRY.unregister(REGISTRY._names_to_collectors['python_gc_objects_collected_total'])
+
 
 class MetricsInterceptor(ServerInterceptor):
   registry: CollectorRegistry
-  grpc_server_request_count: Counter
-  grpc_server_response_count: Counter
-  grpc_server_latency_seconds: Histogram
+  delphai_request_count: Counter
+  delphai_response_count: Counter
+  delphai_latency_seconds: Histogram
 
   def __init__(self, registry: CollectorRegistry = REGISTRY) -> None:
     self.registry = registry
-    self.grpc_server_request_count = Counter(
-      "grpc_server_request_count",
+    self.delphai_request_count = Counter(
+      "delphai_request_count",
       "Total number of RPCs started on the server.",
       ["grpc_service", "grpc_method"],
       registry=registry,
     )
-    self.grpc_server_response_count = Counter(
-      "grpc_server_response_count",
+    self.delphai_response_count = Counter(
+      "delphai_response_count",
       "Total number of RPCs completed on the server, regardless of success or failure.",
       ["grpc_type", "grpc_service", "grpc_method", "grpc_code"],
       registry=registry)
-    self.grpc_server_latency_seconds = Histogram(
-      "grpc_server_latency_seconds",
+    self.delphai_latency_seconds = Histogram(
+      "delphai_latency_seconds",
       "Histogram of response latency (seconds)",
       ["grpc_type", "grpc_service", "grpc_method"],
       registry=registry,
@@ -69,7 +73,7 @@ class MetricsInterceptor(ServerInterceptor):
     try:
       start = default_timer()
       grpc_service_name, grpc_method_name, _ = self.split_method_call(handler_call_details)
-      self.grpc_server_request_count.labels(
+      self.delphai_request_count.labels(
         grpc_service=grpc_service_name,
         grpc_method=grpc_method_name,
       ).inc()
@@ -78,7 +82,7 @@ class MetricsInterceptor(ServerInterceptor):
         result = await continuation(handler_call_details)
         grpc_type = self.get_method_type(result.request_streaming, result.response_streaming)
         grpc_code = StatusCode.OK
-        self.grpc_server_response_count.labels(
+        self.delphai_response_count.labels(
           grpc_type=grpc_type,
           grpc_service=grpc_service_name,
           grpc_method=grpc_method_name,
@@ -87,7 +91,7 @@ class MetricsInterceptor(ServerInterceptor):
         return result
       except AioRpcError as ex:
         grpc_code = ex.code()
-        self.grpc_server_response_count.labels(
+        self.delphai_response_count.labels(
           grpc_type=grpc_type,
           grpc_service=grpc_service_name,
           grpc_method=grpc_method_name,
@@ -97,7 +101,7 @@ class MetricsInterceptor(ServerInterceptor):
       finally:
         elapsed = default_timer() - start
         logging.info(f'[{grpc_code}] {grpc_service_name}/{grpc_method_name} [{round(elapsed * 1000, 2)}ms]')
-        self.grpc_server_latency_seconds.labels(
+        self.delphai_latency_seconds.labels(
           grpc_type=grpc_type,
           grpc_service=grpc_service_name,
           grpc_method=grpc_method_name,
